@@ -1,4 +1,4 @@
-/*  $Id: SoundMixer.h,v 1.2 2004/10/24 00:32:28 sarrazip Exp $
+/*  $Id: SoundMixer.h,v 1.4 2010/05/16 01:50:19 sarrazip Exp $
     SoundMixer.h - Sound mixer based on the SDL_mixer library
 
     flatzebra - Generic 2D Game Engine library
@@ -38,19 +38,19 @@ public:
     class Error
     {
     public:
-	Error(const std::string &s) : errMsg(s) {}
-	const std::string &what() const { return errMsg; }
+        Error(const std::string &s) : errMsg(s) {}
+        const std::string &what() const { return errMsg; }
     private:
-	std::string errMsg;
+        std::string errMsg;
     };
 
     SoundMixer(int numChannels = 8) throw(Error);
     /*  Initializes the SDL_mixer system at a rate of 11025 Hz, mono.
-	'numChannels' must be the number of channels to be allocated.
-	SDL must already have been initialized.
-	If the SDL_mixer initialization fails, throws the error message
-	as an exception.
-	Only one instance of this class should be created.
+        'numChannels' must be the number of channels to be allocated.
+        SDL must already have been initialized.
+        If the SDL_mixer initialization fails, throws the error message
+        as an exception.
+        Only one instance of this class should be created.
     */
 
     ~SoundMixer();
@@ -62,39 +62,43 @@ public:
     {
     public:
 
-	Chunk();
-	/*  Initializes an empty sound chunk.  Call init() after this.
-	*/
+        Chunk();
+        /*  Initializes an empty sound chunk.  Call init() after this.
+        */
 
-	Chunk(const std::string &wavFilename) throw(Error);
-	/*  Calls init() with 'wavFilename' and it if returns a (non-empty)
-	    error message, throws it as an exception.
-	*/
+        Chunk(const std::string &wavFilename) throw(Error);
+        /*  Calls init() with 'wavFilename' and it if returns a (non-empty)
+            error message, throws it as an exception.
+        */
 
-	void init(const std::string &wavFilename) throw(Error);
-	/*  Loads the WAV file whose name is given.
-	    If the load fails, throws the error message as an exception.
-	*/
+        void init(const std::string &wavFilename) throw(Error);
+        /*  Loads the WAV file whose name is given.
+            If the load fails, throws the error message as an exception.
+        */
 
-	~Chunk();
-	/*  Frees the resources used by the chunk.
-	*/
+        ~Chunk();
+        /*  Frees the resources used by the chunk.
+        */
 
     private:
-	Mix_Chunk *sample;
-	friend class SoundMixer;
+        Mix_Chunk *sample;
+        friend class SoundMixer;
+
+        // Forbidden operations:
+        Chunk(const Chunk &);
+        Chunk &operator = (const Chunk &);
     };
 
 
     void playChunk(Chunk &theSound) throw(Error);
     /*  Schedules 'theSound' to be played now on a free unreserved channel.
-	On failure, throws the error message as an exception.
+        On failure, throws the error message as an exception.
     */
 
 
 private:
 
-    /*	Forbidden operations:
+    /*        Forbidden operations:
     */
     SoundMixer(const SoundMixer &x);
     SoundMixer &operator = (const SoundMixer &x);
