@@ -1,4 +1,4 @@
-/*  $Id: Sprite.cpp,v 1.2 2008/01/04 04:04:40 sarrazip Exp $
+/*  $Id: Sprite.cpp,v 1.4 2010/05/16 01:50:19 sarrazip Exp $
     Sprite.cpp - Sprite in a 2D game.
 
     flatzebra - Generic 2D Game Engine library
@@ -36,9 +36,9 @@ inline T &
 boundVariable(T &var, T lowerLimit, T upperLimit)
 {
     if (var < lowerLimit)
-	var = lowerLimit;
+        var = lowerLimit;
     else if (var > upperLimit)
-	var = upperLimit;
+        var = upperLimit;
     return var;
 }
 
@@ -50,24 +50,24 @@ uint32_t Sprite::idGenerator = 0;
 
 
 Sprite::Sprite(const PixmapArray &pixmapArray,
-		const Couple &_pos,
-		const Couple &_speed,
-		const Couple &_accel,
-		const Couple &_collBoxPos,
-		const Couple &_collBoxSize)
+                const Couple &_pos,
+                const Couple &_speed,
+                const Couple &_accel,
+                const Couple &_collBoxPos,
+                const Couple &_collBoxSize)
   : currentPixmapIndex(0),
     values(NULL),
     numUserValues(0),
+    thePixmapArray(&pixmapArray),
     pos(_pos),
     speed(_speed),
     accel(_accel),
+    size(pixmapArray.getImageSize()),
     timeToLive(0),
     collBoxPos(_collBoxPos),
     collBoxSize(_collBoxSize),
     id(++idGenerator)
 {
-    thePixmapArray = &pixmapArray;
-    size = thePixmapArray->getImageSize();
 }
 
 
@@ -86,14 +86,14 @@ bool Sprite::collidesWithSprite(const Sprite &s) const
     const Couple &size2 = s2.collBoxSize;
 
     if (pos1.x + size1.x <= pos2.x)  // s1 at the left of s2
-	return false;
+        return false;
     if (pos1.y + size1.y <= pos2.y)  // s1 above s2
-	return false;
+        return false;
     if (pos2.x + size2.x <= pos1.x)  // s1 at the right of s2
-	return false;
+        return false;
     if (pos2.y + size2.y <= pos1.y)  // s1 below s2
-	return false;
-    
+        return false;
+
     return true;
 }
 
